summaryrefslogtreecommitdiff
path: root/tools/update-babel-eslint.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/update-babel-eslint.sh')
-rwxr-xr-xtools/update-babel-eslint.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/tools/update-babel-eslint.sh b/tools/update-babel-eslint.sh
index 2b6a4e0ee9..6e5971e4ef 100755
--- a/tools/update-babel-eslint.sh
+++ b/tools/update-babel-eslint.sh
@@ -2,7 +2,7 @@
# Shell script to update babel-eslint in the source tree to the latest release.
# Depends on npm and node being in $PATH.
# This script must be be in the tools directory when it runs because it uses
# $BASH_SOURCE[0] to determine directories to work in.
@@ -15,11 +15,11 @@ npm init --yes
npm install --global-style --no-bin-links --production --no-package-lock babel-eslint@latest
-# Install dmn if it is not in path.
-type -P dmn || npm install -g dmn
-
# Use dmn to remove some unneeded files.
-dmn -f clean
+npx dmn@1.0.11 -f clean
+# Use removeNPMAbsolutePaths to remove unused data in package.json.
+# This avoids churn as absolute paths can change from one dev to another.
+npx removeNPMAbsolutePaths@1.0.4 .
cd ..
mv babel-eslint-tmp/node_modules/babel-eslint node_modules/babel-eslint
@@ -2,7 +2,7 @@
# Shell script to update babel-eslint in the source tree to the latest release.
-# Depends on npm and node being in $PATH.
+# Depends on npm, npx, and node being in $PATH.
# This script must be be in the tools directory when it runs because it uses
# $BASH_SOURCE[0] to determine directories to work in.